=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2011-12-19 13:23:58 +0000
+++ bzrlib/fetch.py	2012-01-24 01:01:04 +0000
@@ -203,16 +203,16 @@
         revs = list(revs)
         while revs:
             for tree in self.source.revision_trees(revs[:100]):
-                if tree.inventory.revision_id is None:
-                    tree.inventory.revision_id = tree.get_revision_id()
+                if tree.root_inventory.revision_id is None:
+                    tree.root_inventory.revision_id = tree.get_revision_id()
                 yield tree
             revs = revs[100:]
 
     def _find_root_ids(self, revs, parent_map, graph):
         revision_root = {}
         for tree in self.iter_rev_trees(revs):
-            revision_id = tree.inventory.root.revision
             root_id = tree.get_root_id()
+            revision_id = tree.get_file_revision(root_id, u"")
             revision_root[revision_id] = root_id
         # Find out which parents we don't already know root ids for
         parents = set()

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2012-01-24 00:16:15 +0000
+++ bzrlib/mutabletree.py	2012-01-24 01:01:04 +0000
@@ -408,7 +408,7 @@
         :seealso Inventory.apply_delta: For details on the changes parameter.
         """
         self.flush()
-        inv = self.inventory
+        inv = self.root_inventory
         inv.apply_delta(changes)
         self._write_inventory(inv)
 

=== modified file 'bzrlib/plugins/weave_fmt/workingtree.py'
--- bzrlib/plugins/weave_fmt/workingtree.py	2012-01-06 14:09:04 +0000
+++ bzrlib/plugins/weave_fmt/workingtree.py	2012-01-24 01:01:04 +0000
@@ -105,7 +105,7 @@
                          _bzrdir=a_bzrdir,
                          _control_files=branch.control_files)
         basis_tree = branch.repository.revision_tree(revision_id)
-        if basis_tree.inventory.root is not None:
+        if basis_tree.get_root_id() is not None:
             wt.set_root_id(basis_tree.get_root_id())
         # set the parent list and cache the basis tree.
         if _mod_revision.is_null(revision_id):

=== modified file 'bzrlib/tests/per_repository/test_commit_builder.py'
--- bzrlib/tests/per_repository/test_commit_builder.py	2012-01-24 00:16:15 +0000
+++ bzrlib/tests/per_repository/test_commit_builder.py	2012-01-24 01:01:04 +0000
@@ -264,7 +264,7 @@
             if not builder.supports_record_entry_contents:
                 raise tests.TestNotApplicable("CommitBuilder doesn't support "
                     "record_entry_contents")
-            entry = tree.inventory['foo-id']
+            entry = tree.root_inventory['foo-id']
             self.assertRaises(errors.RootMissing,
                 builder.record_entry_contents, entry, [], 'foo', tree,
                     tree.path_content_summary('foo'))
@@ -287,7 +287,7 @@
             ie = inventory.make_entry('directory', '', None,
                     tree.get_root_id())
             delta, version_recorded, fs_hash = builder.record_entry_contents(
-                ie, [parent_tree.inventory], '', tree,
+                ie, [parent_tree.root_inventory], '', tree,
                 tree.path_content_summary(''))
             # Regardless of repository root behaviour we should consider this a
             # pointless commit.
@@ -374,10 +374,10 @@
                 if not builder.supports_record_entry_contents:
                     raise tests.TestNotApplicable("CommitBuilder doesn't "
                         "support record_entry_contents")
-                parent_invs = [basis.inventory]
+                parent_invs = [basis.root_inventory]
                 builder.will_record_deletes()
                 if builder.record_root_entry:
-                    ie = basis.inventory.root.copy()
+                    ie = basis.root_inventory.root.copy()
                     delta, _, _ = builder.record_entry_contents(ie, parent_invs,
                         '', tree, tree.path_content_summary(''))
                     if delta is not None:
@@ -434,9 +434,9 @@
                         "support record_entry_contents")
                 builder.will_record_deletes()
                 if builder.record_root_entry is True:
-                    parent_invs = [basis.inventory]
-                    del basis.inventory.root.children['foo']
-                    builder.record_entry_contents(basis.inventory.root,
+                    parent_invs = [basis.root_inventory]
+                    del basis.root_inventory.root.children['foo']
+                    builder.record_entry_contents(basis.root_inventory.root,
                         parent_invs, '', tree, tree.path_content_summary(''))
                 # the delta should be returned, and recorded in _basis_delta
                 delta = builder.record_delete("foo", "foo-id")
@@ -869,17 +869,17 @@
                 parent_tree = tree.basis_tree()
                 parent_tree.lock_read()
                 self.addCleanup(parent_tree.unlock)
-                parent_invs = [parent_tree.inventory]
+                parent_invs = [parent_tree.root_inventory]
                 for parent_id in parent_ids[1:]:
                     parent_invs.append(tree.branch.repository.revision_tree(
-                        parent_id).inventory)
+                        parent_id).root_inventory)
                 # root
                 builder.record_entry_contents(
                     inventory.make_entry('directory', '', None,
                         tree.get_root_id()), parent_invs, '', tree,
                         tree.path_content_summary(''))
                 def commit_id(file_id):
-                    old_ie = tree.inventory[file_id]
+                    old_ie = tree.root_inventory[file_id]
                     path = tree.id2path(file_id)
                     ie = inventory.make_entry(tree.kind(file_id), old_ie.name,
                         old_ie.parent_id, file_id)
@@ -891,7 +891,7 @@
                         tree, content_summary)
 
                 file_id = tree.path2id(new_name)
-                parent_id = tree.inventory[file_id].parent_id
+                parent_id = tree.root_inventory[file_id].parent_id
                 if parent_id != tree.get_root_id():
                     commit_id(parent_id)
                 # because a change of some sort is meant to have occurred,
@@ -993,7 +993,7 @@
                 self.assertEqual(inv_sha1, builder.inv_sha1)
             self.assertIs(None, builder.new_inventory)
             rev2 = builder.commit('')
-            new_inventory = builder.revision_tree().inventory
+            new_inventory = builder.revision_tree().root_inventory
             new_entry = new_inventory[file_id]
             if delta_against_basis:
                 expected_delta = (name, new_name, file_id, new_entry)

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2011-12-21 14:25:26 +0000
+++ bzrlib/tests/test_bundle.py	2012-01-24 01:01:04 +0000
@@ -945,7 +945,8 @@
         self.tree1.commit('message', rev_id='revid1')
         bundle = self.get_valid_bundle('null:', 'revid1')
         tree = self.get_bundle_tree(bundle, 'revid1')
-        self.assertEqual('revid1', tree.inventory.root.revision)
+        root_revision = tree.get_file_revision(tree.get_root_id())
+        self.assertEqual('revid1', root_revision)
 
     def test_install_revisions(self):
         self.tree1 = self.make_branch_and_tree('b1')

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2011-12-19 17:39:35 +0000
+++ bzrlib/transform.py	2012-01-24 01:01:04 +0000
@@ -47,7 +47,7 @@
 """)
 from bzrlib.errors import (DuplicateKey, MalformedTransform,
                            ReusingTransform, CantMoveRoot,
-                           ExistingLimbo, ImmortalLimbo, NoFinalPath,
+                           ImmortalLimbo, NoFinalPath,
                            UnableCreateSymlink)
 from bzrlib.filters import filtered_output_bytes, ContentFilterContext
 from bzrlib.osutils import (
@@ -57,7 +57,6 @@
     pathjoin,
     sha_file,
     splitpath,
-    supports_executable,
     )
 from bzrlib.progress import ProgressPhase
 from bzrlib.symbol_versioning import (
@@ -2058,10 +2057,16 @@
         pass
 
     @property
+    @deprecated_method(deprecated_in((2, 5, 0)))
     def inventory(self):
         """This Tree does not use inventory as its backing data."""
         raise NotImplementedError(_PreviewTree.inventory)
 
+    @property
+    def root_inventory(self):
+        """This Tree does not use inventory as its backing data."""
+        raise NotImplementedError(_PreviewTree.root_inventory)
+
     def get_root_id(self):
         return self._transform.final_file_id(self._transform.root)
 

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2012-01-24 00:16:15 +0000
+++ bzrlib/tree.py	2012-01-24 01:01:04 +0000
@@ -775,14 +775,8 @@
     inventory = property(_get_inventory,
                          doc="Inventory of this Tree")
 
-    def _unpack_file_id(self, file_id):
-        if isinstance(file_id, tuple):
-            if len(file_id) != 0:
-                raise ValueError("nested trees not yet supported: %r" % file_id)
-            file_id = file_id[0]
-        return self.inventory, file_id
-
     def _get_root_inventory(self):
+        assert self._inventory is not None, "INV MISSING %r" % self
         return self._inventory
 
     root_inventory = property(_get_root_inventory,
@@ -798,6 +792,7 @@
             if len(file_id) != 0:
                 raise ValueError("nested trees not yet supported: %r" % file_id)
             file_id = file_id[0]
+        assert self.root_inventory is not None, "foo %r" % self.root_inventory
         return self.root_inventory, file_id
 
     @needs_read_lock
@@ -1265,7 +1260,7 @@
         :param file_id: The file_id to lookup.
         """
         try:
-            inventory = tree.inventory
+            inventory = tree.root_inventory
         except NotImplementedError:
             # No inventory available.
             try:

=== modified file 'bzrlib/vf_repository.py'
--- bzrlib/vf_repository.py	2012-01-24 00:16:15 +0000
+++ bzrlib/vf_repository.py	2012-01-24 01:01:04 +0000
@@ -2442,7 +2442,7 @@
         invs_sent_so_far = set([_mod_revision.NULL_REVISION])
         inventory_cache = lru_cache.LRUCache(50)
         null_inventory = from_repo.revision_tree(
-            _mod_revision.NULL_REVISION).inventory
+            _mod_revision.NULL_REVISION).root_inventory
         # XXX: ideally the rich-root/tree-refs flags would be per-revision, not
         # per-repo (e.g.  streaming a non-rich-root revision out of a rich-root
         # repo back into a non-rich-root repo ought to be allowed)

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2012-01-24 00:16:15 +0000
+++ bzrlib/workingtree.py	2012-01-24 01:01:04 +0000
@@ -379,10 +379,6 @@
                                               list_current=list_current)
         return [tr for tr in iterator if tr is not None]
 
-    def all_file_ids(self):
-        """See Tree.iter_all_file_ids"""
-        raise NotImplementedError(self.all_file_ids)
-
     def __repr__(self):
         return "<%s of %s>" % (self.__class__.__name__,
                                getattr(self, 'basedir', None))
@@ -2085,17 +2081,17 @@
         inv, inv_file_id = self._unpack_file_id(file_id)
         return inv.has_id(inv_file_id)
 
-    @symbol_versioning.deprecated_method(symbol_versioning.deprecated_in((2, 4, 0)))
-    def __iter__(self):
+    def all_file_ids(self):
         """Iterate through file_ids for this tree.
 
         file_ids are in a WorkingTree if they are in the working inventory
         and the working file exists.
         """
-        inv = self._inventory
-        for path, ie in inv.iter_entries():
+        ret = set()
+        for path, ie in self.iter_entries_by_dir():
             if osutils.lexists(self.abspath(path)):
-                yield ie.file_id
+                ret.add(ie.file_id)
+        return ret
 
     @needs_tree_write_lock
     def set_last_revision(self, new_revision):
@@ -2157,7 +2153,7 @@
                 _mod_revision.NULL_REVISION)
         else:
             rt = self.branch.repository.revision_tree(revision_ids[0])
-        self._write_inventory(rt.inventory)
+        self._write_inventory(rt.root_inventory)
         self.set_parent_ids(revision_ids)
 
     def flush(self):
@@ -2452,7 +2448,7 @@
             raise errors.ObjectNotLocked(self)
 
         if from_dir is None and include_root is True:
-            yield ('', 'V', 'directory', self.inventory.root.file_id, self.inventory.root)
+            yield ('', 'V', 'directory', self.get_root_id(), self.root_inventory.root)
         # Convert these into local objects to save lookup times
         pathjoin = osutils.pathjoin
         file_kind = self._kind
@@ -2471,7 +2467,7 @@
                 return
             from_dir_abspath = pathjoin(self.basedir, from_dir)
         else:
-            inv = self.inventory
+            inv = self.root_inventory
             from_dir_id = inv.root.file_id
             from_dir_abspath = self.basedir
         children = os.listdir(from_dir_abspath)

=== modified file 'bzrlib/workingtree_3.py'
--- bzrlib/workingtree_3.py	2012-01-06 14:09:04 +0000
+++ bzrlib/workingtree_3.py	2012-01-24 01:01:04 +0000
@@ -221,7 +221,7 @@
         try:
             basis_tree = branch.repository.revision_tree(revision_id)
             # only set an explicit root id if there is one to set.
-            if basis_tree.inventory.root is not None:
+            if basis_tree.get_root_id() is not None:
                 wt.set_root_id(basis_tree.get_root_id())
             if revision_id == _mod_revision.NULL_REVISION:
                 wt.set_parent_trees([])

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2012-01-24 00:16:15 +0000
+++ bzrlib/workingtree_4.py	2012-01-24 01:01:04 +0000
@@ -1339,7 +1339,7 @@
         # being created.
         self._inventory = None
         # generate a delta,
-        delta = inv._make_delta(self.inventory)
+        delta = inv._make_delta(self.root_inventory)
         # and apply it.
         self.apply_inventory_delta(delta)
         if had_inventory:
@@ -1928,13 +1928,20 @@
         """Return the revision id for this tree."""
         return self._revision_id
 
-    def _get_inventory(self):
+    def _get_root_inventory(self):
         if self._inventory is not None:
             return self._inventory
         self._must_be_locked()
         self._generate_inventory()
         return self._inventory
 
+    root_inventory = property(_get_root_inventory,
+                         doc="Inventory of this Tree")
+
+    @deprecated_method(deprecated_in((2, 5, 0)))
+    def _get_inventory(self):
+        return self.root_inventory
+
     inventory = property(_get_inventory,
                          doc="Inventory of this Tree")
 

